export declare function convert(data: SwaggerSpec, options?: ConverterOptions): Promise<string>;
/**
 * Default name resolver which resolve name as PascalCase from path string.
 */
export declare function PascalCaseNameResolver(path: string, pathDefinition: PathDefinition, options: ConverterOptions): string;
export interface ConverterOptions {
    namespace?: string;
    withQuery?: boolean;
    sortProps?: boolean;
    nameResolver?: (path: string, pathDefinition: PathDefinition, options: ConverterOptions) => string;
}
export interface SwaggerSpec {
    [key: string]: any;
    paths?: {
        [path: string]: PathDefinition;
    };
    definitions?: {
        [name: string]: SchemaDefinition;
    };
}
export interface PathDefinition {
    get?: {
        [key: string]: any;
        description?: string;
        parameters?: ParameterObject[];
    };
    post?: any;
}
/** http://swagger.io/specification/#parameterObject */
export interface ParameterObject {
    name: string;
    in: "query" | "header" | "path" | "formData" | "body";
    required?: boolean;
    type: SchemaType;
    enum?: string[];
    items?: ItemsObject;
}
/** http://swagger.io/specification/#itemsObject */
export interface ItemsObject {
    type?: SchemaType;
    enum?: string[];
}
export interface SchemaDefinition {
    id?: string;
    type: string;
    properties?: SchemaProperties;
    required?: string[];
}
export interface SchemaProperties {
    [key: string]: {
        format?: string;
        type?: SchemaType;
        "$ref"?: string;
        enum?: string[];
        items?: {
            format?: string;
            type?: SchemaType;
            enum?: string[];
        };
    };
}
export declare type SchemaType = "string" | "number" | "integer" | "boolean" | "array" | "file";
